package Gnome2::VFS::Install::Files;

$self = {
          'inc' => '-pthread -DORBIT2=1 -I/usr/include/gnome-vfs-2.0 -I/usr/lib/gnome-vfs-2.0/include -I/usr/include/bonobo-activation-2.0 -I/usr/include/libbonobo-2.0 -I/usr/include/gconf/2 -I/usr/include/glib-2.0 -I/usr/lib/glib-2.0/include -I/usr/include/orbit-2.0   -I build',
          'typemaps' => [
                          'vfs2perl.typemap',
                          'vfs.typemap'
                        ],
          'deps' => [
                      'Glib'
                    ],
          'libs' => '-pthread -Wl,--export-dynamic -lgnomevfs-2 -lbonobo-2 -lgconf-2 -lbonobo-activation -lORBit-2 -lm -lgmodule-2.0 -ldl -lgthread-2.0 -lglib-2.0  '
        };


# this is for backwards compatiblity
@deps = @{ $self->{deps} };
@typemaps = @{ $self->{typemaps} };
$libs = $self->{libs};
$inc = $self->{inc};

	$CORE = undef;
	foreach (@INC) {
		if ( -f $_ . "/Gnome2/VFS/Install/Files.pm") {
			$CORE = $_ . "/Gnome2/VFS/Install/";
			last;
		}
	}

1;
